@@ -19,6 +19,7 @@
 /* Headers we may want to use. */
 #define STDC_HEADERS 1
 #define _GNU_SOURCE 1
+/* #undef HAVE_ALIGNED_ALLOC */
 #define HAVE_ALLOCA_H 1
 #define HAVE_ARPA_INET_H 1
 #define HAVE_ASM_TERMBITS_H 1
@@ -163,7 +164,6 @@
 #define HAVE_LRAND48 1
 #define HAVE_LOCALTIME_R 1
 #define HAVE_LSTAT 1
-#define HAVE_MEMALIGN 1
 /* #define HAVE_MLOCK 1 see Bug#54662 */
 #define HAVE_NL_LANGINFO 1
 #define HAVE_MADVISE 1
@@ -529,17 +529,17 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 8
-#define MYSQL_VERSION_PATCH 3
+#define MYSQL_VERSION_MINOR 9
+#define MYSQL_VERSION_PATCH 2
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.8.3"
+#define PACKAGE_STRING "MySQL Server 10.9.2"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.8.3"
-#define VERSION "10.8.3"
+#define PACKAGE_VERSION "10.9.2"
+#define VERSION "10.9.2"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
